
<a id='changelog-2023.6.9'></a>
## [2023.6.9] - 2023-06-09

### Added

- Added the `mitol-django-google-sheets-deferrals` app

- Added implementation of filter_ignored_rows to request handler

- Added DeferralRequestAdmin

### Changed

- Updated release version format

- Set default_auto_field in app config

<a id='changelog-2023.5.30'></a>
## [2023.5.30] - 2023-05-30

### Added

- Added the `mitol-django-google-sheets-deferrals` app

- Added implementation of filter_ignored_rows to request handler

### Changed

- Updated release version format

- Set default_auto_field in app config

<a id='changelog-2023.5.25'></a>
## [2023.5.25] - 2023-05-25

### Added

- Added the `mitol-django-google-sheets-deferrals` app

### Changed

- Updated release version format

- Set default_auto_field in app config

<a id='changelog-2023.5.23'></a>
## [2023.5.23] - 2023-05-23

### Added

- Added the `mitol-django-google-sheets-deferrals` app

### Changed

- Updated release version format
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project uses date-based versioning.
